import java.lang.*;

/*
-------------------------------------------------------------------------------
Model presa-depredador (normalitzat)
-------------------------------------------------------------------------------
Dades: dt (mida del pas), imax (passos que es volen calcular), jmax
       (iteracions per estabilitzar), nx0 (nombre inicial especie x),
       ny0 (nombre inicial especie y), aa (influencia d'y sobre x), bb
       (influencia de x sobre y), rx (taxa de creixement x), dd (mortalitat
       especie y), Kx (capacitat especie x)
Resultats: Al fitxer "edos4.dat". Cada fila representa un instant de temps.
           La primera columna es el temps, la segona el nombre (sense
           normalitzar) de membres de l'especie x i la tercera el mateix
           pero de l'especie y.
Dades de prova: dt=0.05 imax=200 jmax=1 nx0=200 ny0=300 aa=0.00075 bb=0.75
                rx=2.0 dd=1.0 Kx=1000 ==>
                0.000000 200.000000 300.000000
                0.050000 213.750000 286.687500
                0.100000 228.258118 274.076599
                0.150000 243.527740 262.132263
                0.200000 259.556061 250.821045  
                  ...      ....        ...
Observacions: Totes les quantitats es refereixen al model sense normalitzar.
              Nomes jmax=1 esta justificat teoricament.
-------------------------------------------------------------------------------
*/

public class Edos4Calculs {
	double dt,nx0,ny0,aa,bb,rx,dd,Kx,temps[],trajx[],trajy[];
	int imax;

	Edos4Calculs(float dt0,int imax0,float nx00,float ny00,float aa0,float bb0,float rx0,float dd0,float Kx0) {
		double dx,dy,x0,y0,t0,x,y,t,xf,yf,tf,xm,ym,tm;
		int i,j,jmax;

		dt = (double) dt0;
		nx0 = (double) nx00;
		ny0 = (double) ny00;
		aa = (double) aa0;
		bb = (double) bb0;
		rx = (double) rx0;
		dd = (double) dd0;
		Kx = (double) Kx0;
		imax = imax0;
		jmax = 1;
		temps = new double[imax];
		trajx = new double[imax];
		trajy = new double[imax];

		t0=0;
		x=nx0;
		y=ny0;
		t=t0;
		xf=nx0;
		yf=ny0;
		temps[0]=t0;
		trajx[0]=nx0;
		trajy[0]=ny0;
		for(i=0;i<imax;i++) {
			tm=t+dt/2.0;
			for(j=0;j<jmax;j++) {
				xm=(x+xf)/2.0;
				ym=(y+yf)/2.0;
				dx=dt*xm*(rx*(Kx-xm)/Kx-aa*ym);
				dy=dt*ym*(aa*bb*xm-dd);
				xf=x+dx;
				yf=y+dy;
			}
			x=xf;
			y=yf;
			t=t+dt; 
			temps[i]=t;
			trajx[i]=x;
			trajy[i]=y;        
		}
	}
}
